@@ -5,9 +5,14 @@ use warnings;
 use base 'My::Builder';
 
 use File::Spec::Functions qw(catdir catfile rel2abs);
-use My::Utility qw(check_header check_prereqs_libs);
+use My::Utility qw(check_header check_prereqs_libs check_prereqs_tools);
 use Config;
 
+# $Config{cc} tells us to use gcc-4, but it is not there by default
+if($^O eq 'cygwin') {
+  $My::Utility::cc = 'gcc';
+}
+
 my $inc_lib_candidates = {
   '/usr/local/include' => '/usr/local/lib',
   '/usr/local/include/smpeg' => '/usr/local/lib',
@@ -61,6 +66,9 @@ sub build_binaries {
     elsif($pack->{pack} =~ m/^(SDL_mixer)$/ && !$self->_is_gnu_make($self->_get_make)) {
       print "SKIPPING package '" . $pack->{dirname} . "' (GNU Make needed)...\n";
     }
+    elsif($pack->{pack} =~ m/^(SDL_Pango)$/ && !check_prereqs_tools('pkg-config')) {
+      print "SKIPPING package '" . $pack->{dirname} . "' (pkg-config needed)...\n";
+    }
     else {
       print "BUILDING package '" . $pack->{dirname} . "'...\n";
       my $srcdir = catfile($build_src, $pack->{dirname});
@@ -71,12 +79,19 @@ sub build_binaries {
 
       # do './configure ...'
       my $run_configure = 'y';
-      $run_configure = $self->prompt("Run ./configure for '$pack->{pack}' again?", "n") if (-f "config.status");
+      $run_configure = $self->prompt("Run ./configure for '$pack->{pack}' again?", "y") if (-f "config.status");
       if (lc($run_configure) eq 'y') {
         my $cmd = $self->_get_configure_cmd($pack->{pack}, $prefixdir);
-        print "Configuring $pack->{pack}...\n";
+        print "Configuring package '$pack->{pack}'...\n";
         print "(cmd: $cmd)\n";
-        $self->do_system($cmd) or die "###ERROR### [$?] during ./configure ... ";
+        unless($self->do_system($cmd)) {
+          if(-f "config.log" && open(CONFIGLOG, "<config.log")) {
+            print "config.log:\n";
+            print while <CONFIGLOG>;
+            close(CONFIGLOG);
+          }
+          die "###ERROR### [$?] during ./configure for package '$pack->{pack}'...";
+        }
       }
 
       # do 'make install'
@@ -102,7 +117,7 @@ sub _get_configure_cmd {
 
   # NOTE: all ugly IFs concerning ./configure params have to go here
 
-  if(($pack eq 'SDL_gfx') && $Config{archname} =~ /(powerpc|ppc|64|2level)/i) {
+  if(($pack eq 'SDL_gfx') && $Config{archname} =~ /(powerpc|ppc|64|2level|alpha)/i) {
     $extra .= ' --disable-mmx';
   }
   
@@ -110,7 +125,7 @@ sub _get_configure_cmd {
     $extra .= ' --disable-video-ps3';
   }
 
-  if($^O eq 'darwin' && !check_header($self->get_additional_cflags, 'X11/Xlib.h')) {
+  if($pack eq 'SDL' && $^O eq 'darwin' && !check_header($self->get_additional_cflags, 'X11/Xlib.h')) {
     $extra .= ' --without-x';
   }
 
@@ -145,7 +160,7 @@ sub _get_configure_cmd {
   #  $extra_cflags .= ' -I/usr/X11R6/include';
   #  $extra_ldflags .= ' -L/usr/X11R6/lib';
   #}
-  
+
   if($pack =~ /^zlib/) {
     # does not support params CFLAGS=...
     $cmd = "./configure --prefix=$prefixdir";
@@ -154,10 +169,14 @@ sub _get_configure_cmd {
     $cmd = "./configure --prefix=$prefixdir --enable-static=no --enable-shared=yes $extra" .
            " CFLAGS=\"$extra_cflags\" LDFLAGS=\"$extra_ldflags\"";
   }
-  
+
+  if($pack ne 'SDL' && $^O eq 'openbsd') {
+    $cmd = "LD_LIBRARY_PATH=\"$prefixdir/lib:\$LD_LIBRARY_PATH\" $cmd";
+  }
+
   # we need to have $prefixdir/bin in PATH while running ./configure
   $cmd = "PATH=\"$prefixdir/bin:\$PATH\" $cmd";
-  
+
   return $cmd;
 }
 
